#!/usr/bin/env python
# -*- coding: utf-8 -*-

PATH_SRC=""
PATH_TMP_MIF="tmp/mif"
PATH_TMP_SHP="tmp/shp"
PATH_OUT=""


import sys,os,zipfile,tarfile,shutil,logging
logging.basicConfig(format='[%(levelname)s] %(message)s', level=logging.DEBUG)

try:
    PATH_SRC=sys.argv[1]
    PATH_OUT=sys.argv[2]
except:
    print """
usage   : python %s src_dir dst_dir
exemple : python %s mif shp
    """%(sys.argv[0],sys.argv[0])


def emptyDir(dirn):
    '''Purge a directory content'''
    files = os.listdir(dirn)
    for fn in files:
        path = os.path.join (dirn, fn)
        if os.path.isdir(path):
            emptyDir(path)
        else:
            retval = os.unlink(path)

def dirEntries(dir_name, subdir, *args):
    '''Return a list of file names found in directory 'dir_name'
    If 'subdir' is True, recursively access subdirectories under 'dir_name'.
    Additional arguments, if any, are file extensions to match filenames. Matched
        file names are added to the list.
    If there are no additional arguments, all files found in the directory are
        added to the list.
    Example usage: fileList = dirEntries(r'H:\TEMP', False, 'txt', 'py')
        Only files with 'txt' and 'py' extensions will be added to the list.
    Example usage: fileList = dirEntries(r'H:\TEMP', True)
        All files and all the files in subdirectories under H:\TEMP will be added
        to the list.
    '''
    fileList = []
    for file in os.listdir(dir_name):
        dirfile = os.path.join(dir_name, file)
        if os.path.isfile(dirfile):
            if not args:
                fileList.append(dirfile)
            else:
                if os.path.splitext(dirfile)[1][1:] in args:
                    fileList.append(dirfile)
        # recursively access file names in subdirectories
        elif os.path.isdir(dirfile) and subdir:
            fileList.extend(dirEntries(dirfile, subdir, *args))
    return fileList


def convertLot(srcPath):
    logging.info('checking %s'%srcPath)
    srcName=os.path.split(srcPath)[1]
    shpFilepath=os.path.join(PATH_OUT,srcName)

    # flag proceed
    proceed = False

    # is shp missing ?
    if not(os.path.isfile(shpFilepath)):
        logging.info('MIF not found, proceeding...')
        proceed=True

    # shp exists
    else:
        # is shp too old ?
        srcDate=os.path.getmtime(srcPath)
        mifDate=os.path.getmtime(shpFilepath)
        if srcDate>mifDate:
            logging.info('dataset %s is newer than SHP file, new convertion requested'%srcName)
            proceed=True
        else:
            logging.info('dataset %s is older than SHP file, skipping'%srcName)


    if proceed:

        # vidange repertoire tmp zip
        emptyDir(PATH_TMP_MIF)
        emptyDir(PATH_TMP_SHP)

        # decompression du lot
        logging.info('extracting %s into %s' % (srcPath,PATH_TMP_MIF))
        f=zipfile.ZipFile(srcPath,'r')
        f.extractall(PATH_TMP_MIF)
        f.close()

        fnMifList=dirEntries(PATH_TMP_MIF,True,"mif","MIF")

        # convertion shape
        logging.info('converting %s files to mif format' % len(fnMifList))
        for pathMif in fnMifList:
            fnMif=os.path.split(pathMif)[1]
            fnShp=fnMif[:-3]+"SHP"
            pathShp=os.path.join(PATH_TMP_SHP,fnShp)
            cmd='ogr2ogr %s %s 2>&1'%(pathShp,pathMif)
            logging.info(cmd)
            os.system(cmd)
        # logging.info(dirEntries(PATH_TMP_MIF,True))
        zipout=zipfile.ZipFile(shpFilepath,'w')
        for fnShp in dirEntries(PATH_TMP_SHP,False):
            zipout.write(fnShp)
        zipout.close()








for fn in dirEntries(PATH_SRC,True,"zip","ZIP"):
    convertLot(fn)

